==> knt_bloc-3.2.1.tar.gz: lib/src/bloc/events.dart <==
part of 'blocs.dart';

abstract class BaseEvent {
  const BaseEvent({String? tag}) : this._tag = tag;

  /// Defined ID for this event, will be used for handle event & state
  final String? _tag;

  String get tag => _tag ?? runtimeType.toString();

  /// Override this getter if this event need connect to remote data source
  bool get needCheckConnection => false;
}

class BaseLoadingEvent extends BaseEvent {
  const BaseLoadingEvent({super.tag});
}

class BaseErrorEvent extends BaseEvent {
  const BaseErrorEvent({
    required this.exception,
    super.tag,
  });

  final KntException exception;
}

class BasePagingEvent<Q> extends BaseEvent {
  const BasePagingEvent({
    this.queryData,
    this.limit = defaultLimitPaging,
    this.isFirstRequest = false,
    this.needLoading = true,
    super.tag,
  });

  final Q? queryData;
  final int limit;
  final bool isFirstRequest;
  final bool needLoading;
}

class ResetBlocEvent extends BaseEvent {
  const ResetBlocEvent({
    this.needToCancelRunningTask = true,
    this.needToNotify = false,
  });

  final bool needToCancelRunningTask;
  final bool needToNotify;
}

class CancelRunningTaskEvent extends BaseEvent {}

/// Trigger this event when you want to add new data into existing list
class AddToPagingDataEvent<D> extends BaseEvent {
  const AddToPagingDataEvent({
    required this.newData,
    this.focusOnUpdatedData = true,
    super.tag,
  });

  final D newData;

  /// Whether we should focus (scroll/animate) to the latest updated data in paging list
  final bool focusOnUpdatedData;
}

/// Trigger this event when you want to edit a data from existing list
class EditPagingDataEvent<D> extends BaseEvent {
  const EditPagingDataEvent({
    required this.updatedData,
    required this.currentPosition,
    this.focusOnUpdatedData = true,
    super.tag,
  });

  final D updatedData;

  /// Position where old data was
  final int currentPosition;

  /// Whether we should focus (scroll/animate) to the latest updated data in paging list
  final bool focusOnUpdatedData;
}

/// Trigger this event when you want to delete a data from existing list
class DeleteFromPagingDataEvent<D> extends BaseEvent {
  const DeleteFromPagingDataEvent({
    required this.data,
    this.focusOnUpdatedData = true,
    super.tag,
  });

  final D data;

  /// Whether we should focus (scroll/animate) to the latest updated data in paging list
  final bool focusOnUpdatedData;
}

==> knt_bloc-4.0.0.tar.gz: lib/src/bloc/events.dart <==
part of 'blocs.dart';

abstract class BaseEvent {
  const BaseEvent({String? tag}) : _tag = tag;

  /// Defined ID for this event, will be used for handle event & state.
  final String? _tag;

  String get tag => _tag ?? runtimeType.toString();

  /// Override this getter if this event need connect to remote data source.
  bool get needCheckConnection => false;
}

class BaseLoadingEvent extends BaseEvent {
  const BaseLoadingEvent({super.tag});
}

class BaseErrorEvent extends BaseEvent {
  const BaseErrorEvent({
    required this.exception,
    super.tag,
  });

  final KntException exception;
}

class BasePagingEvent<Q> extends BaseEvent {
  const BasePagingEvent({
    this.queryData,
    this.limit = defaultLimitPaging,
    this.isFirstRequest = false,
    this.needLoading = true,
    super.tag,
  });

  final Q? queryData;
  final int limit;
  final bool isFirstRequest;
  final bool needLoading;
}

class ResetBlocEvent extends BaseEvent {
  const ResetBlocEvent({
    this.needToCancelRunningTask = true,
    this.needToNotify = false,
  });

  final bool needToCancelRunningTask;
  final bool needToNotify;
}

class CancelRunningTaskEvent extends BaseEvent {}

/// Trigger this event when you want to add new data into existing list.
class AddToPagingDataEvent<D> extends BaseEvent {
  const AddToPagingDataEvent({
    required this.newData,
    this.focusOnUpdatedData = true,
    super.tag,
  });

  final D newData;

  /// Whether we should focus (scroll/animate) to the latest updated data
  /// in paging list.
  final bool focusOnUpdatedData;
}

/// Trigger this event when you want to edit a data from existing list.
class EditPagingDataEvent<D> extends BaseEvent {
  const EditPagingDataEvent({
    required this.updatedData,
    required this.currentPosition,
    this.focusOnUpdatedData = true,
    super.tag,
  });

  final D updatedData;

  /// Position where old data was.
  final int currentPosition;

  /// Whether we should focus (scroll/animate) to the latest updated data
  /// in paging list.
  final bool focusOnUpdatedData;
}

/// Trigger this event when you want to delete a data from existing list.
class DeleteFromPagingDataEvent<D> extends BaseEvent {
  const DeleteFromPagingDataEvent({
    required this.data,
    this.focusOnUpdatedData = true,
    super.tag,
  });

  final D data;

  /// Whether we should focus (scroll/animate) to the latest updated data
  /// in paging list.
  final bool focusOnUpdatedData;
}
